@@ -14,9 +14,10 @@ sv_to_arg (SV * sv,
 	GITypeTag tag = g_type_info_get_tag (type_info);
 
 	if (!gperl_sv_is_defined (sv))
-		/* Interfaces and void types need to be able to handle undef
-		 * separately. */
+		/* Interfaces, booleans and void types need to be able to
+		 * handle undef separately.*/
 		if (!may_be_null && tag != GI_TYPE_TAG_INTERFACE
+		                 && tag != GI_TYPE_TAG_BOOLEAN
 		                 && tag != GI_TYPE_TAG_VOID)
 		{
 			if (arg_info) {
@@ -228,7 +229,7 @@ arg_to_sv (GIArgument * arg,
 		package = gperl_package_from_type (gtype);
 		if (!package)
 			package = g_type_name (gtype);
-		return package ? newSVpv (package, PL_na) : &PL_sv_undef;
+		return package ? newSVpv (package, 0) : &PL_sv_undef;
 	    }
 
 	    case GI_TYPE_TAG_ARRAY:
@@ -258,7 +259,7 @@ arg_to_sv (GIArgument * arg,
 
 	    case GI_TYPE_TAG_FILENAME:
 	    {
-		SV *sv = newSVpv (arg->v_string, PL_na);
+		SV *sv = newSVpv (arg->v_string, 0);
 		if (own)
 			g_free (arg->v_string);
 		return sv;
